@@ -1,7 +1,7 @@
 import logging
 
 
-LOG_LEVEL_DEFAULT = 100
+LOG_LEVEL_DEFAULT = logging.WARNING
 LOG_LEVEL_DEFAULT_STR = "DEFAULT"
 LOG_LEVEL_AUDIT = 25
 LOG_LEVEL_AUDIT_STR = "AUDIT"
@@ -9,7 +9,6 @@ LOG_LEVEL_AUDIT_STR = "AUDIT"
 AUDIT_LOG_FORMAT = "send request method:{} path:{} headers:{} args:{}"
 
 logging.addLevelName(LOG_LEVEL_AUDIT, "AUDIT")
-logging.addLevelName(LOG_LEVEL_DEFAULT, "DEFAULT")
 
 
 def get_log_level(level=str) -> int:
