@@ -9,4 +9,5 @@ class VersionTest(TestCase):
         runner = CliRunner()
         result = runner.invoke(main, ['--version'])
         self.assertEqual(result.exit_code, 0)
-        self.assertEqual(result.output, 'launchable-cli, version {}\n'.format(__version__))
+        self.assertEqual(
+            result.output, 'launchable-cli, version {}\n'.format(__version__))
